import logging
import os

from jnpr.junos import Device
from lxml import etree

from inventory_provider import config

SCHEMA_FILENAME = os.path.realpath(os.path.join(
    os.path.dirname(__file__),
    "data",
    "juniper-netconf.xsd"
))


def _load_netconf(hostname, ssh_params):
    dev = Device(
        host=hostname,
        user=ssh_params['username'],
        ssh_private_key_file=ssh_params['private-key'])
    dev.open()
    print(dev.facts)
    return dev.rpc.get_config()


if __name__ == "__main__":

    logging.basicConfig(level=logging.INFO)

    TEST_DATA_DIR = os.path.dirname(__file__)
    CONFIG_FILENAME = "config.json"
    SCHEMA_FILENAME = os.path.join(TEST_DATA_DIR, "juniper-netconf.xsd")

    with open("config.json") as f:
        params = config.load(f)
    for r in params['routers']:
        logging.info("router: " + r['hostname'])
        netconf = _load_netconf(r['hostname'], params['ssh'])
        filename = os.path.join(
            TEST_DATA_DIR,
            "%s-netconf.xml" % r['hostname'])
        with open(filename, 'w') as f:
            f.write(etree.tostring(netconf, encoding='unicode'))
